@@ -29,6 +29,13 @@ class APIEndpoints(Enum):
     USERS = f"{api_prefix}/users"
     SNAPSHOTS = f"{api_prefix}/snapshots"
     DASHBOARD_SNAPSHOTS = f"{api_prefix}/dashboard/snapshots"
+    PLAYLISTS = f"{api_prefix}/playlists"
+    TEAMS = f"{api_prefix}/teams"
+    QUERY_HISTORY = f"{api_prefix}/query-history"
+    REPORTING = f"{api_prefix}/reports/email"
+    LICENSING = f"{api_prefix}/licensing"
+    FRONTEND = f"{api_prefix}/frontend"
+    LOGIN = f"{api_prefix}/login"
 
 
 class RequestsMethods(Enum):
@@ -218,3 +225,75 @@ class UserObject(NamedTuple):
     name: str
     login: str
     theme: str
+
+
+class PlaylistObject(NamedTuple):
+    """The class includes all necessary variables to generate a playlist object
+
+    Args:
+        name (str): Specify the name of the playlist
+        interval (str): Specify the interval of the playlist
+        items (list): Specify a list of PlaylistItemObjects
+    """
+
+    name: str
+    interval: str
+    items: list
+
+
+class PlaylistItemObject(NamedTuple):
+    """The class includes all necessary variables to generate a playlist item object that is necessary to update a playlist
+
+    Args:
+        type (str): Specify the type of the playlist item
+        value (str): Specify the value of the playlist item
+        order (int): Specify the order of the playlist item
+        title (str): Specify the title of the playlist item
+    """
+
+    type: str
+    value: str
+    order: int
+    title: str
+
+
+class TeamObject(NamedTuple):
+    """The class includes all necessary variables to generate a team object that is necessary to create a team
+
+    Args:
+        name (str): Specify the name of the team
+        email (str): Specify the email of the team
+        org_id (int): Specify the org_id of the team
+    """
+
+    name: str
+    email: str
+    org_id: int
+
+
+class QueryDatasourceObject(NamedTuple):
+    """The class includes all necessary variables to generate a query datasource object that is necessary to create a query history object
+
+    Args:
+        type (str): Specify the type of the datasource query
+        uid (str): Specify the uid of the datasource query
+    """
+
+    type: str
+    uid: str
+
+
+class QueryObject(NamedTuple):
+    """The class includes all necessary variables to generate a query object that is necessary to create a query history
+
+    Args:
+        ref_id (str): Specify the ref_id of the query history
+        key (str): Specify the key of the query history
+        scenario_id (str): Specify the scenario_id of the query history
+        datasource (QueryDatasourceObject): Specify the datasource of the type QueryDatasourceObject
+    """
+
+    ref_id: str
+    key: str
+    scenario_id: str
+    datasource: QueryDatasourceObject
